package main

import "github.com/goplus/lib/c"

func main() {
	c.Printf(c.Str("Hello, world!\n"))
}
